==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/InputGroupItemDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
/**
 * @hidden
 */
var InputGroupItemDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(InputGroupItemDescriptionMetadata, _super);
    function InputGroupItemDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    InputGroupItemDescriptionMetadata.b = function (a) {
        if (InputGroupItemDescriptionMetadata.a == null) {
            InputGroupItemDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            InputGroupItemDescriptionMetadata.c(InputGroupItemDescriptionMetadata.a);
        }
        if (a.g(InputGroupItemDescriptionMetadata.a)) {
            return;
        }
        a.s(InputGroupItemDescriptionMetadata.a);
    };
    InputGroupItemDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:XInputGroupItem");
        a.item("Name", "String");
    };
    InputGroupItemDescriptionMetadata.d = function (a) {
        InputGroupItemDescriptionMetadata.b(a);
        a.t("InputGroupItem", InputGroupItemDescriptionMetadata.a);
    };
    InputGroupItemDescriptionMetadata.$t = markType(InputGroupItemDescriptionMetadata, 'InputGroupItemDescriptionMetadata');
    InputGroupItemDescriptionMetadata.a = null;
    return InputGroupItemDescriptionMetadata;
}(Base));
export { InputGroupItemDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/InputGroupItemDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
/**
 * @hidden
 */
var InputGroupItemDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(InputGroupItemDescriptionMetadata, _super);
    function InputGroupItemDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    InputGroupItemDescriptionMetadata.b = function (a) {
        if (InputGroupItemDescriptionMetadata.a == null) {
            InputGroupItemDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            InputGroupItemDescriptionMetadata.c(InputGroupItemDescriptionMetadata.a);
        }
        if (a.j(InputGroupItemDescriptionMetadata.a)) {
            return;
        }
        a.y(InputGroupItemDescriptionMetadata.a);
    };
    InputGroupItemDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:XInputGroupItem");
        a.item("Name", "String");
    };
    InputGroupItemDescriptionMetadata.d = function (a) {
        InputGroupItemDescriptionMetadata.b(a);
        a.z("InputGroupItem", InputGroupItemDescriptionMetadata.a);
    };
    InputGroupItemDescriptionMetadata.$t = markType(InputGroupItemDescriptionMetadata, 'InputGroupItemDescriptionMetadata');
    InputGroupItemDescriptionMetadata.a = null;
    return InputGroupItemDescriptionMetadata;
}(Base));
export { InputGroupItemDescriptionMetadata };
